User prompt
Player can move their vehicle by touching anywhere on the screen. The vehicle moves relative to the speed and direction at which the player moves their finger
User prompt
Why isn’t the touch event handler working?
User prompt
The player can move their vehicle by dragging it with one finger
User prompt
The player vehicle continuously shoots bullets that move from the front of the vehicle to the top of the screen
User prompt
Double the sprite size
User prompt
Player vehicle should start at bottom of the screen
User prompt
Initialize player’s vehicle sprite
User prompt
Neon Drift: Sky Havoc
Initial prompt
Top down cyberpunk themed shoot em up where you pilot a flying car
/**** * Classes ****/ // Bullet class var Bullet = Container.expand(function () { var self = Container.call(this); // Attach the bullet sprite var bulletSprite = self.attachAsset('bullet', { anchorX: 0.5, anchorY: 0.5 }); // Set bullet speed self.speed = -10; // This is automatically called every game tick, if the bullet is attached! self.update = function () { self.y += self.speed; // Destroy the bullet if it goes off the screen if (self.y < -self.height) { self.destroy(); } }; }); // Player's vehicle class var PlayerVehicle = Container.expand(function () { var self = Container.call(this); // Attach the player's vehicle sprite var vehicleSprite = self.attachAsset('playerVehicle', { anchorX: 0.5, anchorY: 0.5, scaleX: 2, scaleY: 2 }); // This is automatically called every game tick, if the player's vehicle is attached! self.update = function () { // Fire a bullet every 30 ticks if (LK.ticks % 30 == 0) { var bullet = new Bullet(); bullet.x = self.x; bullet.y = self.y - self.height / 2 - bullet.height / 2; game.addChild(bullet); } }; }); /**** * Initialize Game ****/ // Add player's vehicle to the game var game = new LK.Game({ backgroundColor: 0x000000 }); /**** * Game Code ****/ // Add player's vehicle to the game var playerVehicle = game.addChild(new PlayerVehicle()); // Position player's vehicle at the bottom of the screen playerVehicle.x = 2048 / 2; playerVehicle.y = 2732 - playerVehicle.height / 2; // Declare a variable to track the node being dragged var dragNode = null; // Add a touch down event handler to the game game.down = function (x, y, obj) { // Set playerVehicle as the node being dragged dragNode = playerVehicle; // Store the initial touch position dragNode.initialTouchPosition = { x: x, y: y }; // Store the initial position of the playerVehicle dragNode.initialPosition = { x: playerVehicle.x, y: playerVehicle.y }; }; // Add a touch move event handler to the game game.move = function (x, y, obj) { // If a node is being dragged, update its position relative to the speed and direction at which the player moves their finger if (dragNode) { dragNode.x = dragNode.initialPosition.x + (x - dragNode.initialTouchPosition.x); dragNode.y = dragNode.initialPosition.y + (y - dragNode.initialTouchPosition.y); } }; // Add a touch up event handler to the game game.up = function (x, y, obj) { // If a node was being dragged, stop dragging it if (dragNode) { dragNode = null; } };
===================================================================
--- original.js
+++ change.js
@@ -61,19 +61,27 @@
// Declare a variable to track the node being dragged
var dragNode = null;
// Add a touch down event handler to the game
game.down = function (x, y, obj) {
- // If the player's vehicle was touched, set it as the node being dragged
- if (playerVehicle.intersects(obj)) {
- dragNode = playerVehicle;
- }
+ // Set playerVehicle as the node being dragged
+ dragNode = playerVehicle;
+ // Store the initial touch position
+ dragNode.initialTouchPosition = {
+ x: x,
+ y: y
+ };
+ // Store the initial position of the playerVehicle
+ dragNode.initialPosition = {
+ x: playerVehicle.x,
+ y: playerVehicle.y
+ };
};
// Add a touch move event handler to the game
game.move = function (x, y, obj) {
- // If a node is being dragged, update its position to the touch position
+ // If a node is being dragged, update its position relative to the speed and direction at which the player moves their finger
if (dragNode) {
- dragNode.x = x;
- dragNode.y = y;
+ dragNode.x = dragNode.initialPosition.x + (x - dragNode.initialTouchPosition.x);
+ dragNode.y = dragNode.initialPosition.y + (y - dragNode.initialTouchPosition.y);
}
};
// Add a touch up event handler to the game
game.up = function (x, y, obj) {
Neon cyberpunk flying car. Single Game Texture. Blank background. High contrast. No shadows. Top-down
Fluffy cloud viewed from the top. Single Game Sprite Texture. No background.
This type of cloud but in a fine mist
One single Fluffy cloud viewed from the top. Single Game Sprite. No background. No shadow
Mini rocket projectile from a video game. No background.
Terminator style 2D enemy ship. Facing dead south. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows
Circular ball projectile from a video game. No background.
Make it look like night time